@@ -11,7 +11,10 @@
 // KF
 #include <KAboutData>
 #include <KCrash>
-#include <KDBusService>
+#include <config-bomber.h>
+#if HAVE_DBUS
+    #include <KDBusService>
+#endif
 #include <KLocalizedString>
 
 #define HAVE_KICONTHEME __has_include(<KIconTheme>)
@@ -28,7 +31,7 @@
 #include "bomber.h"
 #include "bomber_version.h"
 
-int main(int argc, char ** argv)
+int main(int argc, char **argv)
 {
 #if HAVE_KICONTHEME
     KIconTheme::initTheme();
@@ -43,19 +46,18 @@ int main(int argc, char ** argv)
 #endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
 #endif // HAVE_STYLE_MANAGER
 
-
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("bomber"));
 
-    KAboutData about(QStringLiteral("bomber"), i18n("Bomber"),
+    KAboutData about(QStringLiteral("bomber"),
+                     i18n("Bomber"),
                      QStringLiteral(BOMBER_VERSION_STRING),
                      i18n("Arcade bombing game"),
-                     KAboutLicense::GPL, i18n("(C) 2007 John-Paul Stanford"),
+                     KAboutLicense::GPL,
+                     i18n("(C) 2007 John-Paul Stanford"),
                      QString(),
                      QStringLiteral("https://apps.kde.org//bomber"));
-    about.addAuthor(i18n("John-Paul Stanford"), QString(),
-                    QStringLiteral("jp@stanwood.org.uk"));
-    about.addAuthor(i18n("Mehmet Emre"), i18n("Porting to QGraphicsView."),
-                    QStringLiteral("maemre2@gmail.com"));
+    about.addAuthor(i18n("John-Paul Stanford"), QString(), QStringLiteral("jp@stanwood.org.uk"));
+    about.addAuthor(i18n("Mehmet Emre"), i18n("Porting to QGraphicsView."), QStringLiteral("maemre2@gmail.com"));
     KAboutData::setApplicationData(about);
 
     KCrash::initialize();
@@ -65,7 +67,9 @@ int main(int argc, char ** argv)
     parser.process(app);
     about.processCommandLine(&parser);
 
+#if HAVE_DBUS
     KDBusService service;
+#endif
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("bomber")));
 
